/************************************************************************
 * $Id: prayer-demo.c,v 1.11 2004/07/18 09:44:20 thamer Exp $
 *
 * ------------
 * Description:
 * ------------
 *  Copyright (c) 2003, Arabeyes, Thamer Mahmoud
 *
 *  A full featured Muslim Prayer Times calculator
 *
 *  NOTE: This is a small example that uses libprayer. For more info
 *  on filling the structures and on supported methods read "prayer.h"
 *
 * -----------------
 * Revision Details:    (Updated by Revision Control System)
 * -----------------
 *  $Date: 2004/07/18 09:44:20 $
 *  $Author: thamer $
 *  $Revision: 1.11 $
 *  $Source: /home/arabeyes/cvs/projects/itl/libs/prayertime/src/prayer-demo.c,v $
 *
 * (www.arabeyes.org - under LGPL license - see COPYING file)
 *
 * Ported to Java by Ahmed Talaat (aa_talaat@yahoo.com) 5 Dec 2004
 ************************************************************************/
package code;

public class PrayerDemo {

	public static void main(String[] args) {
		int i, deg, min;
	    double sec;
	    String cityName ="Dubai";
	    double qibla;

	    Location loc = new Location();
	    PrayerDate date= new PrayerDate();
	    Method conf = new Method();
	    PrayerTimes prayerTimes = new PrayerTimes();

	    Prayer[] ptList;
	    Prayer imsaak, nextImsaak, nextFajr;
	    DMS dms;

	    /* fill the Date structure */
	    date.setDay(11);
	    date.setMonth(12);
	    date.setYear(2004);
	    /* fill the location info. structure */
	    loc.setDegreeLat(25.25);
	    loc.setDegreeLong(55.35);
	    loc.setGmtDiff(4);
	    loc.setDst(0);
	    loc.setSeaLevel(0);
	    loc.setPressure(1010);
	    loc.setTemperature(10);

	    /* auto fill the method structure. Have a look at prayer.h for a
	     * list of supported methods */
	    conf.autoFillPrayerMethod(Method.FIXED_ISHAA);
	    conf.setRound(0);

	    /* Call the main function to fill the Prayer times array of
	     * structures */
	    ptList = prayerTimes.getPrayerTimes (loc, conf, date);

	    /* Call functions for other prayer times and qibla */
	    imsaak = prayerTimes.getImsaak (loc, conf, date);
	    nextFajr = prayerTimes.getNextDayFajr (loc, conf, date);
	    nextImsaak = prayerTimes.getNextDayImsaak (loc, conf, date);
	    qibla = prayerTimes.getNorthQibla(loc);


	    /* Show the results */
	    System.out.println("Prayer schedule for "+cityName+" on "
	    					+date.getDay()+"/"+date.getMonth()+"/"+date.getYear());

	    dms = prayerTimes.decimal2Dms (loc.getDegreeLat());
	    System.out.println("Latitude="+Math.abs(dms.getDegree())+" "+
	    					Math.abs(dms.getMinute())+" "+
							Math.abs(dms.getSecond())+
							((loc.getDegreeLat()>=0) ? 'N' : 'S'));
	    dms = prayerTimes.decimal2Dms (loc.getDegreeLong());
	    System.out.println("Longitude="+Math.abs(dms.getDegree())+" "+
				Math.abs(dms.getMinute())+" "+
				Math.abs(dms.getSecond())+
				((loc.getDegreeLong()>=0) ? 'E' : 'W'));
	    dms = prayerTimes.decimal2Dms (qibla);
	    System.out.println("Qibla="+Math.abs(dms.getDegree())+" "+
				Math.abs(dms.getMinute())+" "+
				Math.abs(dms.getSecond())+
				((qibla>=0) ? 'W' : 'E'));

	    System.out.println("Prayer Times");

	    for (i = 0; i < 6; i++){
	    	boolean extreme;
	    	if (ptList[i].getIsExtreme()==0){
	    		extreme = false;
	    	}else {
	    		extreme = true;
	    	}
	    	System.out.print(ptList[i].getHour()+":"+ptList[i].getMinute()+":"
	    						+ptList[i].getSecond()+(extreme ? '*' : ' ' )+" ");
	    }

	    System.out.println("\nTomorrow's Fajr "+nextFajr.getHour()+":"+
	    					nextFajr.getMinute());
	    System.out.println("Tomorrow's Imsaak "+nextImsaak.getHour()+":"+
	    					nextImsaak.getMinute());
	    System.out.println("Today's Imsaak "+imsaak.getHour()+":"+
	    					imsaak.getMinute());

	    return;
	}
}
